@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,9 @@
 
 package com.openexchange.messaging.generic.groupware;
 
-import gnu.trove.TIntArrayList;
-import gnu.trove.TIntProcedure;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.procedure.TIntProcedure;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -68,7 +69,7 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link MessagingGenericDeleteListener}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessagingGenericDeleteListener implements DeleteListener {
@@ -84,15 +85,15 @@ public final class MessagingGenericDeleteListener implements DeleteListener {
         if (DeleteEvent.TYPE_USER != event.getType()) {
             return;
         }
-        final DatabaseService databaseService = getService(DatabaseService.class);
+        getService(DatabaseService.class);
         /*
          * Writable connection
          */
         final int contextId = event.getContext().getContextId();
         PreparedStatement stmt = null;
         try {
-            final int userId = event.getSession().getUserId();
-            final TIntArrayList confIds;
+            final int userId = event.getId();
+            final TIntList confIds;
             {
                 ResultSet rs = null;
                 try {
