@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,8 @@
 package com.openexchange.messaging.generic.internet;
 
 import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
 import javax.mail.Flags;
 import javax.mail.Folder;
 import javax.mail.internet.MimeMessage;
@@ -57,6 +59,7 @@ import com.openexchange.mail.mime.MIMEDefaultSession;
 import com.openexchange.messaging.MessagingException;
 import com.openexchange.messaging.MessagingExceptionCodes;
 import com.openexchange.messaging.MessagingMessage;
+import com.openexchange.messaging.ParameterizedMessagingMessage;
 import com.openexchange.messaging.generic.internal.InternalUtility;
 import com.openexchange.messaging.generic.internal.InternalUtility.ParsedFlags;
 
@@ -66,7 +69,9 @@ import com.openexchange.messaging.generic.internal.InternalUtility.ParsedFlags;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since Open-Xchange v6.16
  */
-public class MimeMessagingMessage extends MimeMessagingBodyPart implements MessagingMessage {
+public class MimeMessagingMessage extends MimeMessagingBodyPart implements ParameterizedMessagingMessage {
+
+    private static final long serialVersionUID = -1043416749304746683L;
 
     private static final Flags ALL_COLOR_LABELS;
 
@@ -112,12 +117,15 @@ public class MimeMessagingMessage extends MimeMessagingBodyPart implements Messa
 
     private String picture;
 
+    private final Map<String, Object> parameters;
+
     /**
      * Initializes a new {@link MimeMessagingMessage}.
      */
     public MimeMessagingMessage() {
         super(new MimeMessage(MIMEDefaultSession.getDefaultSession()), null);
-        this.mimeMessage = (MimeMessage) part;
+        mimeMessage = (MimeMessage) part;
+        parameters = new HashMap<String, Object>(4);
     }
 
     /**
@@ -125,9 +133,10 @@ public class MimeMessagingMessage extends MimeMessagingBodyPart implements Messa
      * 
      * @param mimeMessage The MIME message
      */
-    public MimeMessagingMessage(final MimeMessage mimeMessage) {
+    protected MimeMessagingMessage(final MimeMessage mimeMessage) {
         super(mimeMessage, null);
         this.mimeMessage = mimeMessage;
+        parameters = new HashMap<String, Object>(4);
     }
 
     public int getColorLabel() throws MessagingException {
@@ -224,8 +233,8 @@ public class MimeMessagingMessage extends MimeMessagingBodyPart implements Messa
         try {
             final String[] strings = mimeMessage.getFlags().getUserFlags();
             Flags newFlags = new Flags();
-            for (int i = 0; i < strings.length; i++) {
-                final String uf = strings[i];
+            for (final String string : strings) {
+                final String uf = string;
                 if (!InternalUtility.isColorLabel(uf) && !MessagingMessage.USER_FORWARDED.equalsIgnoreCase(uf) && !MessagingMessage.USER_READ_ACK.equalsIgnoreCase(uf)) {
                     newFlags.add(uf);
                 }
@@ -308,20 +317,50 @@ public class MimeMessagingMessage extends MimeMessagingBodyPart implements Messa
     public void setId(final String id) {
         this.id = id;
     }
-    
+
     public String getPicture() {
         return picture;
     }
-    
-    
+
     /**
      * Sets the picture
-     *
+     * 
      * @param picture The picture url
      */
-    public void setPicture(String picture) {
+    public void setPicture(final String picture) {
         this.picture = picture;
     }
 
+    public String getUrl() throws MessagingException {
+        return null;
+    }
+
+    public Map<String, Object> getParameters() {
+        return parameters;
+    }
+
+    public Object getParameter(final String name) {
+        return parameters.get(name);
+    }
+
+    public void putParameter(final String name, final Object value) {
+        parameters.put(name, value);
+    }
+
+    public boolean putParameterIfAbsent(final String name, final Object value) {
+        if (parameters.containsKey(name)) {
+            return false;
+        }
+        parameters.put(name, value);
+        return true;
+    }
+
+    public void clearParameters() {
+        parameters.clear();
+    }
+
+    public boolean containsParameter(final String name) {
+        return parameters.containsKey(name);
+    }
 
 }
